@@ -51,7 +51,11 @@ enum cli_result_code {
     cli_not_all_columns_specified = -16,
     cli_not_fetched = -17, 
     cli_already_updated = -18, 
-    cli_login_failed = -19
+    cli_login_failed = -19,
+    cli_empty_parameter = -20,
+    cli_closed_connection = -21,
+    cli_table_already_exists = -22, 
+    cli_not_implemented = -23
 };
 
 enum cli_var_type {
@@ -196,6 +200,31 @@ int GIGABASE_DLL_ENTRY cli_open(char const*   server_url,
 				char_t const* password,
 				int           pooled_connection);
 
+enum cli_open_attributes { 
+    cli_open_default      = 0x0, 
+    cli_open_readonly     = 0x1, 
+    cli_open_truncate     = 0x2, 
+    cli_open_no_buffering = 0x4
+};
+/*********************************************************************
+ * cli_create
+ *     Create conecntion to the local database
+ * Parameters:
+ *     databasePath - path to the database file
+ *     transactionCommitDelay - trasnaction commit delay (specify 0 to disable)
+ *     openAttr - mask of cli_open_attributes
+ *     poolSize - size of page pool (in pages), specify 0 to let GigaBASE automaticaly detect pool size
+ * Returns:
+ *     >= 0 - connection descriptor to be used in all other cli calls
+ *     <  0 - error code as described in cli_result_code enum
+ */
+
+int GIGABASE_DLL_ENTRY cli_create(char_t const* databasePath, 
+				  unsigned      transactionCommitDelay, 
+				  int           openAttr, 
+				  size_t        poolSize);
+
+
 /*********************************************************************
  * cli_close
  *     Close session
@@ -475,10 +504,18 @@ int GIGABASE_DLL_ENTRY cli_precommit(int session);
  */
 int GIGABASE_DLL_ENTRY cli_abort(int session);
 
+enum cli_field_flags { 
+    cli_hashed           = 1, /* field should be indexed usnig hash table */
+    cli_indexed          = 2, /* field should be indexed using B-Tree */
+    cli_case_insensitive = 4  /* index is case insensitive */
+};
 
 typedef struct cli_field_descriptor { 
     enum cli_var_type type;
+    int               flags;
     char_t const*     name;
+    char_t const*     refTableName;
+    char_t const*     inverseRefFieldName;
 } cli_field_descriptor;
 
 /*********************************************************************
@@ -513,6 +550,51 @@ typedef struct cli_table_descriptor {
  */
 int GIGABASE_DLL_ENTRY cli_show_tables(int session, cli_table_descriptor** tables);
 
+
+
+/*********************************************************************
+ * cli_create_table
+ *     Create new table
+ * Parameters:
+ *     session   - session descriptor as returned by cli_open
+ *     tableName - name of new table
+ *     nFields   - number of columns in the table
+ *     fields    - array with table columns descriptors
+ * Returns:
+ *     result code as described in cli_result_code enum
+ */
+int GIGABASE_DLL_ENTRY cli_create_table(int session, char_t const* tableName, int nFields, 
+					cli_field_descriptor* fields);
+
+/*********************************************************************
+ * cli_drop_table
+ *     drop the table
+ * Parameters:
+ *     session   - session descriptor as returned by cli_open
+ *     tableName - name of deleted table
+ * Returns:
+ *     result code as described in cli_result_code enum
+ */
+int GIGABASE_DLL_ENTRY cli_drop_table(int session, char_t const* tableName);
+
+
+/*********************************************************************
+ * cli_alter_index
+ *     add or remove column index
+ * Parameters:
+ *     session   - session descriptor as returned by cli_open
+ *     tableName - name of the table
+ *     fieldName - name of field
+ *     newFlags  - new flags of the field, if index exists for this field, but is not specified in 
+ *                 <code>newFlags</code> mask, then it will be removed; if index not exists, but is 
+ *                 specified in <code>newFlags</code> mask, then it will be created. *                   
+ * Returns:
+ *     result code as described in cli_result_code enum
+ */
+int GIGABASE_DLL_ENTRY cli_alter_index(int session, char_t const* tableName, char_t const* fieldName, 
+				       int newFlags);
+
+
 #ifdef __cplusplus
 }
 #endif
