@@ -50,7 +50,7 @@ class dbContainer : public dbAnyContainer {
 	return dbAnyContainer::search(cursor, NULL, NULL);
     }
     int spatialSearch(dbCursor<T>& cursor, rectangle const& r, SpatialSearchType type) { 
-	return dbAnyContainer::search(cursor, r, type);
+	return dbAnyContainer::spatialSearch(cursor, r, type);
     }
 	
     
