@@ -17,7 +17,7 @@ const size_t dbDefaultRaidBlockSize = 1024*1024;
 
 class dbFile {
   protected:
-#ifdef _WIN32
+#if defined(_WIN32)
     HANDLE fh;
 #else
     int    fd;
