@@ -289,7 +289,7 @@ class dbEvent {
 	    struct timeval cur_tv;
 	    gettimeofday(&cur_tv, NULL);
 	    abs_ts.tv_sec = cur_tv.tv_sec + timeout; 
-	    abs_ts.tv_nsec = cur_tv.tv_usec;
+	    abs_ts.tv_nsec = cur_tv.tv_usec*1000;
 #endif
 	    pthread_cond_timedwait(&cond, &mutex.cs, &abs_ts);
 	}
@@ -341,7 +341,7 @@ class dbSemaphore {
 	    struct timeval cur_tv;
 	    gettimeofday(&cur_tv, NULL);
 	    abs_ts.tv_sec = cur_tv.tv_sec + timeout; 
-	    abs_ts.tv_nsec = cur_tv.tv_usec;
+	    abs_ts.tv_nsec = cur_tv.tv_usec*1000;
 #endif
 	    pthread_cond_timedwait(&cond, &mutex.cs, &abs_ts);
 	}
